@@ -27,11 +27,8 @@ _SPIRV_OP_INTERNAL(CooperativeMatrixStoreOffsetINTEL,
                    internal::OpCooperativeMatrixStoreOffsetINTEL)
 _SPIRV_OP_INTERNAL(CooperativeMatrixApplyFunctionINTEL,
                    internal::OpCooperativeMatrixApplyFunctionINTEL)
-_SPIRV_OP_INTERNAL(ComplexFMulINTEL, internal::ComplexFMulINTEL)
-_SPIRV_OP_INTERNAL(ComplexFDivINTEL, internal::ComplexFDivINTEL)
 _SPIRV_OP_INTERNAL(MaskedGatherINTEL, internal::OpMaskedGatherINTEL)
 _SPIRV_OP_INTERNAL(MaskedScatterINTEL, internal::OpMaskedScatterINTEL)
-_SPIRV_OP_INTERNAL(RoundFToTF32INTEL, internal::RoundFToTF32INTEL)
 _SPIRV_OP_INTERNAL(TaskSequenceAsyncINTEL, internal::OpTaskSequenceAsyncINTEL)
 _SPIRV_OP_INTERNAL(TaskSequenceCreateINTEL, internal::OpTaskSequenceCreateINTEL)
 _SPIRV_OP_INTERNAL(TaskSequenceGetINTEL, internal::OpTaskSequenceGetINTEL)
@@ -44,18 +41,3 @@ _SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
                    internal::ConvertHandleToSamplerINTEL)
 _SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
                    internal::ConvertHandleToSampledImageINTEL)
-_SPIRV_OP_INTERNAL(PredicatedLoadINTEL,
-                   internal::OpPredicatedLoadINTEL)
-_SPIRV_OP_INTERNAL(PredicatedStoreINTEL,
-                   internal::OpPredicatedStoreINTEL)
-_SPIRV_OP_INTERNAL(FSigmoidINTEL, internal::FSigmoidINTEL)
-_SPIRV_OP_INTERNAL(ClampConvertFToFINTEL,
-                   internal::OpClampConvertFToFINTEL)
-_SPIRV_OP_INTERNAL(StochasticRoundFToFINTEL,
-                   internal::OpStochasticRoundFToFINTEL)
-_SPIRV_OP_INTERNAL(ClampStochasticRoundFToFINTEL,
-                   internal::OpClampStochasticRoundFToFINTEL)
-_SPIRV_OP_INTERNAL(ClampConvertFToSINTEL,
-                   internal::OpClampConvertFToSINTEL)
-_SPIRV_OP_INTERNAL(ClampStochasticRoundFToSINTEL,
-                   internal::OpClampStochasticRoundFToSINTEL)
