@@ -86,12 +86,16 @@ SPIRVType *SPIRVType::getFunctionReturnType() const {
 }
 
 SPIRVType *SPIRVType::getPointerElementType() const {
-  assert(OpCode == OpTypePointer && "Not a pointer type");
+  assert((OpCode == OpTypePointer || OpCode == OpTypeUntypedPointerKHR) &&
+         "Not a pointer type");
+  if (OpCode == OpTypeUntypedPointerKHR)
+    return const_cast<SPIRVType *>(this);
   return static_cast<const SPIRVTypePointer *>(this)->getElementType();
 }
 
 SPIRVStorageClassKind SPIRVType::getPointerStorageClass() const {
-  assert(OpCode == OpTypePointer && "Not a pointer type");
+  assert((OpCode == OpTypePointer || OpCode == OpTypeUntypedPointerKHR) &&
+         "Not a pointer type");
   return static_cast<const SPIRVTypePointer *>(this)->getStorageClass();
 }
 
@@ -190,7 +194,13 @@ bool SPIRVType::isTypeInt(unsigned Bits) const {
   return isType<SPIRVTypeInt>(this, Bits);
 }
 
-bool SPIRVType::isTypePointer() const { return OpCode == OpTypePointer; }
+bool SPIRVType::isTypePointer() const {
+  return OpCode == OpTypePointer || OpCode == OpTypeUntypedPointerKHR;
+}
+
+bool SPIRVType::isTypeUntypedPointerKHR() const {
+  return OpCode == OpTypeUntypedPointerKHR;
+}
 
 bool SPIRVType::isTypeOpaque() const { return OpCode == OpTypeOpaque; }
 
@@ -262,6 +272,14 @@ bool SPIRVType::isTypeVectorOrScalarFloat() const {
   return isTypeFloat() || isTypeVectorFloat();
 }
 
+bool SPIRVType::isSPIRVOpaqueType() const {
+  return isTypeDeviceEvent() || isTypeEvent() || isTypeImage() ||
+         isTypePipe() || isTypeReserveId() || isTypeSampler() ||
+         isTypeSampledImage() || isTypePipeStorage() ||
+         isTypeCooperativeMatrixKHR() || isTypeJointMatrixINTEL() ||
+         isTypeTaskSequenceINTEL();
+}
+
 bool SPIRVTypeStruct::isPacked() const {
   return hasDecorate(DecorationCPacked);
 }
